# python setup.py sdist bdist_wheel
# twine upload --repository-url https://test.pypi.org/legacy/ dist/*
from setuptools import setup, find_packages

setup(
    name='instavm',
    version='0.13.0',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    author='InstaVM',
    author_email='hello@instavm.io',
    description='Official Python SDK for InstaVM APIs',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://instavm.io',
    license='MIT',
    project_urls={
        'Documentation': 'https://instavm.io/docs/sdks/python/overview',
        'Changelog': 'https://instavm.io/docs/sdks/python/changelog',
        'Support': 'https://instavm.io/support',
        'Source': 'https://github.com/BandarLabs/sandbox_client',
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.8',
)
